Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ErrUserNotFound indicates the user was not found ErrUserNotFound = errors.New("user not found") )
Functions ¶
This section is empty.
Types ¶
type Identity ¶
type Identity interface {
// Identifier returns the identifier of that identity
Identifier() *IdentityIdentifier
// Verify a signature over some message using this identity as reference
Verify(msg []byte, sig []byte) error
// Serialize converts an identity to bytes
Serialize() ([]byte, error)
// EnrollmentCertificate Returns the underlying ECert representing this user’s identity.
EnrollmentCertificate() []byte
}
Identity represents a Fabric client identity
type IdentityIdentifier ¶
type IdentityIdentifier struct {
// The identifier of the associated membership service provider
MSPID string
// The identifier for an identity within a provider
ID string
}
IdentityIdentifier is a holder for the identifier of a specific identity, naturally namespaced, by its provider identifier.
type IdentityManager ¶
type IdentityManager interface {
GetSigningIdentity(name string) (SigningIdentity, error)
}
IdentityManager provides management of identities in Fabric network
type IdentityManagerProvider ¶
type IdentityManagerProvider interface {
IdentityManager(orgName string) (IdentityManager, bool)
}
IdentityManagerProvider provides identity management services
type PrivKeyKey ¶
PrivKeyKey is a composite key for accessing a private key in the key store
type Providers ¶
type Providers interface {
UserStore() UserStore
IdentityManagerProvider
}
Providers represents a provider of MSP service.
type SigningIdentity ¶
type SigningIdentity interface {
// Extends Identity
Identity
// Sign the message
Sign(msg []byte) ([]byte, error)
// GetPublicVersion returns the public parts of this identity
PublicVersion() Identity
// PrivateKey returns the crypto suite representation of the private key
PrivateKey() core.Key
}
SigningIdentity is an extension of Identity to cover signing capabilities.
Click to show internal directories.
Click to hide internal directories.