Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Connection ¶
type Connection interface {
// Receive sends events to the given channel
Receive(chan<- interface{})
// Close closes the connection
Close()
// Closed return true if the connection is closed
Closed() bool
}
Connection defines the functions for an event server connection
type ConnectionProvider ¶
type ConnectionProvider func(context context.Client, chConfig fab.ChannelCfg, peer fab.Peer) (Connection, error)
ConnectionProvider creates a Connection.
type EventEndpoint ¶
type EventEndpoint interface {
fab.Peer
// EventURL returns the event URL
EventURL() string
// Opts returns additional options for the connection
Opts() []options.Opt
}
EventEndpoint extends a Peer endpoint and provides the event URL, which may or may not be the same as the Peer URL
Click to show internal directories.
Click to hide internal directories.